@@ -19,6 +19,6 @@ class DataproductDocument(BaseModel):
     accessRights: Optional[common_fields.AccessRights] = common_fields.AccessRights.INTERNAL.value
     keyword: Optional[Sequence] = []
     theme: Optional[Union[str, List[str]]] = ""
-    temporal: Optional[dict] = None
+    temporal: Optional[dict] = {}
     language: Optional[str] = "NO"
     datasets: Optional[List[DatasetDocument]] = []
