@@ -7,14 +7,16 @@ from nav_dcat.fields import common_fields
 
 
 class DatasetDocument(BaseModel):
-    id: str
+    gcpProject: str
+    dataset: str
+    table: str
     title: str
+    description: str
     sources: Optional[List[str]] = []
-    description: Optional[str] = ""
+    long_description: Optional[str] = ""
     modified: Optional[str] = None
     issued: Optional[str] = None
     spatial: Optional[str] = ""
     accessRights: Optional[common_fields.AccessRights] = common_fields.AccessRights.INTERNAL.value
     accessGroups: Optional[AccessGroups] = AccessGroups
     keyword: Optional[Sequence] = []
-    url: Optional[str] = ""
